# unitorch.cli.models.t5

## T5Processor

!!! tip
    **`core/process/t5`** is the section for configuration of T5Processor.

::: unitorch.cli.models.t5.T5Processor

## T5ForGeneration

!!! tip
    **`core/model/generation/t5`** is the section for configuration of T5ForGeneration.

::: unitorch.cli.models.t5.T5ForGeneration
